## RPG Specific Elements

### Character System

{{character_system}}

**Character attributes:**

- Stats (Strength, Dexterity, Intelligence, etc.)
- Classes/roles
- Leveling system
- Skill trees

### Inventory and Equipment

{{inventory_equipment}}

**Equipment system:**

- Item types (weapons, armor, accessories)
- Rarity tiers
- Item stats and modifiers
- Inventory management

### Quest System

{{quest_system}}

**Quest structure:**

- Main story quests
- Side quests
- Quest tracking
- Branching questlines
- Quest rewards

### World and Exploration

{{world_exploration}}

**World design:**

- Map structure (open world, hub-based, linear)
- Towns and safe zones
- Dungeons and combat zones
- Fast travel system
- Points of interest

### NPC and Dialogue

{{npc_dialogue}}

**NPC interaction:**

- Dialogue trees
- Relationship/reputation system
- Companion system
- Merchant NPCs

### Combat System

{{combat_system}}

**Combat mechanics:**

- Combat style (real-time, turn-based, tactical)
- Ability system
- Magic/skill system
- Status effects
- Party composition (if applicable)
